/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.controller;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springblade.modules.shopping.entity.Favorites;
import org.springblade.modules.shopping.vo.FavoritesVO;
import org.springblade.modules.shopping.service.IFavoritesService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * 商品关注表 控制器
 *
 * @author BladeX
 * @since 2022-02-13
 */
@RestController
@AllArgsConstructor
@RequestMapping("shopping/favorites")
@Api(value = "商品关注表", tags = "商品关注表接口")
public class FavoritesController extends BladeController {

	private final IFavoritesService favoritesService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入favorites")
	public R<Favorites> detail(Favorites favorites) {
		Favorites detail = favoritesService.getOne(Condition.getQueryWrapper(favorites));
		return R.data(detail);
	}

	/**
	 * 分页 商品关注表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入favorites")
	public R<IPage<Favorites>> list(Favorites favorites, Query query) {
		IPage<Favorites> pages = favoritesService.page(Condition.getPage(query), Condition.getQueryWrapper(favorites));
		return R.data(pages);
	}

	/**
	 * 自定义分页 商品关注表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入favorites")
	public R<IPage<FavoritesVO>> page(FavoritesVO favorites, Query query) {
		IPage<FavoritesVO> pages = favoritesService.selectFavoritesPage(Condition.getPage(query), favorites);
		return R.data(pages);
	}

	/**
	 * 新增 商品关注表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入favorites")
	public R save(@Valid @RequestBody Favorites favorites) {
		return R.status(favoritesService.save(favorites));
	}

	/**
	 * 修改 商品关注表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入favorites")
	public R update(@Valid @RequestBody Favorites favorites) {
		return R.status(favoritesService.updateById(favorites));
	}

	/**
	 * 新增或修改 商品关注表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入favorites")
	public R submit(@Valid @RequestBody Favorites favorites) {
		return R.status(favoritesService.saveOrUpdate(favorites));
	}

	
	/**
	 * 删除 商品关注表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(favoritesService.removeByIds(Func.toLongList(ids)));
	}

	
}
