/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableLogic;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.time.LocalDateTime;
import java.util.Date;

/**
 * 品牌表实体类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Data
@TableName("t_brands")
@ApiModel(value = "Brands对象", description = "品牌表")
public class Brands implements Serializable {

	private static final long serialVersionUID = 1L;

	/**
	 * 品牌ID
	 */
	@JsonSerialize(using = ToStringSerializer.class)
	@TableId(value = "id", type = IdType.ASSIGN_ID)
	@ApiModelProperty(value = "品牌ID")
	private Long id;
	/**
	 * 品牌名称
	 */
	@ApiModelProperty(value = "品牌名称")
	private String brandName;
	/**
	 * 品牌图标
	 */
	@ApiModelProperty(value = "品牌图标")
	private String brandImg;
	/**
	 * 品牌背景图片
	 */
	@ApiModelProperty(value = "品牌背景图片")
	private String brandBimg;
	/**
	 * 品牌介绍
	 */
	@ApiModelProperty(value = "品牌介绍")
	private String brandDesc;

	/**
	 * 排序
	 */
	private Integer sort;
	/**
	 * 创建时间
	 */
	@ApiModelProperty(value = "创建时间")
	private Date createTime;

	/**
	 * 删除标识   0正常  1逻辑删除
	 */
	@TableLogic
	@ApiModelProperty(value = "删除标识   0正常  1逻辑删除")
	private Integer isDeleted;


}
