/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.modules.shopping.entity;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableLogic;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;

/**
 * 商品规格表实体类
 *
 * @author BladeX
 * @since 2022-02-13
 */
@Data
@TableName("t_goods_specs")
@ApiModel(value = "GoodsSpecs对象", description = "商品规格表")
public class GoodsSpecs implements Serializable {

    private static final long serialVersionUID = 1L;

	@JsonSerialize(using = ToStringSerializer.class)
	@TableId(value = "id", type = IdType.ASSIGN_ID)
    private Long id;
    /**
     * 商品ID
     */
    @ApiModelProperty(value = "商品ID")
    private Long goodsId;
    /**
     * 规格ID字符串
     */
    @ApiModelProperty(value = "规格ID字符串")
    private String specIds;
    /**
     * 市场价
     */
    @ApiModelProperty(value = "市场价")
    private Double marketPrice;
    /**
     * 商品价
     */
    @ApiModelProperty(value = "商品价")
    private Double specPrice;

	@ApiModelProperty(value = "酒票数")
	private Double ticketNum;
    /**
     * 总库存
     */
    @ApiModelProperty(value = "总库存")
    private Integer specStock;
    /**
     * 预警库存
     */
    @ApiModelProperty(value = "预警库存")
    private Integer warnStock;
    /**
     * 销量
     */
    @ApiModelProperty(value = "销量")
    private Integer saleNum;
    /**
     * 是否默认规格
     */
    @ApiModelProperty(value = "是否默认规格")
    private Integer isDefault;
    /**
     * 成本价
     */
    @ApiModelProperty(value = "成本价")
    private Double costPrice;
    /**
     * 删除标识   0正常  1逻辑删除
     */
	@TableLogic
    @ApiModelProperty(value = "删除标识   0正常  1逻辑删除")
    private Integer isDeleted;


}
